@@ -6,7 +6,7 @@
 #          The projects homepage is http://dev.cmsmadesimple.org/projects/content2/
 #          CMS Made Simple is (c) 2004-2010 by Ted Kulp (wishy@cmsmadesimple.org)
 #          The projects homepage is: http://www.cmsmadesimple.org
-# Version: 0.5.1
+# Version: 0.6
 # File   : method.install.php
 # Purpose: installs the module, creates tables and set preferences
 # License: GPL
@@ -21,39 +21,29 @@ $taboptarray = array('mysql' => 'TYPE=MyISAM');
 $dict        = NewDataDictionary($db);
 
 // User Settings
-$flds = "user_id I, content_id I, block_id X, block_display I";
+$flds = "user_id I, content_id I, template_id I, item_id X, item_display I";
 $sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_AdvancedContent_blockdisplay", 
 	$flds, $taboptarray);
 $dict->ExecuteSQLArray($sqlarray);
 
 // User Settings
-$flds = "user_id I, content_id I, block_id X, message_display I";
+$flds = "user_id I, content_id I, template_id I, item_id X, item_display I";
 $sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_AdvancedContent_messagedisplay", 
 	$flds, $taboptarray);
 $dict->ExecuteSQLArray($sqlarray);
 
+// User Settings
+$flds = "user_id I, content_id I, template_id I, item_id X, item_display I";
+$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_AdvancedContent_groupdisplay", 
+	$flds, $taboptarray);
+$dict->ExecuteSQLArray($sqlarray);
+
 $this->CreatePermission('Manage AdvancedContent', 'Manage AdvancedContent');
 $this->CreatePermission('Manage All AdvancedContent Blocks', 'Manage All AdvancedContent Blocks');
 $this->CreatePermission('Manage AdvancedContent Options', 'Manage AdvancedContent Options');
 
 $this->AddEventHandler( 'Core', 'ContentPostRender', false );
 
-$this->SetPreference('uninstall_action', '');
-$this->SetPreference('restrictdirs', false);
-$this->SetPreference('showfilemanagement', true);
-$this->SetPreference('showthumbnailfiles', false);
-$this->SetPreference('allowscaling', true);
-$this->SetPreference('scalingwidth', '');
-$this->SetPreference('scalingheight', '');
-$this->SetPreference('filepickerstyle', 'both');
-$this->SetPreference('makethumbnail', true);
-$this->SetPreference('filepickerwidth', '');
-$this->SetPreference('filepickerheight', '');
-$this->SetPreference('filepickerwidthunit', '');
-$this->SetPreference('filepickerheightunit', '');
-$this->SetPreference('allowupscaling', false);
-$this->SetPreference('usemimetype', false);
-
 $this->Audit( 0, $this->Lang('AdvancedContent'), 
 	$this->Lang('installed',$this->GetVersion()));
 
